@@ -721,13 +721,14 @@ void ChatWindow::sendButtonEnabledProcess()
 	{
 	    PlainTextExporter textExporter(messageEditor->document());
 	    messageText = textExporter.toText();
+	    if (!m_account->onlineStatus().connected() || (session->contact()->isConference() && session->contact()->isTemporary()) || messageText.isEmpty())
+		    sendButton->setEnabled(false);
+	    else
+		    sendButton->setEnabled(true);
 	}
 	else if (smsEditor && smsEditor->isVisible())
-		messageText="hack";
-
-
-	if (!m_account->onlineStatus().connected() || (session->contact()->isConference() && session->contact()->isTemporary()) || messageText.isEmpty())
-		sendButton->setEnabled(false);
-	else
 		sendButton->setEnabled(true);
+
+
+
 }
